⚫️ DeLU (Deep Learning Utilities)
=================================

`Documentation <https://yura52.github.io/delu>`_

.. __INCLUDE_0__

**DeLU is a simple PyTorch toolbox**
aimed at improving the day-to-day experience with PyTorch.

DeLU includes the following submodules:

.. list-table::
   :widths: 20 200
   :header-rows: 0

   * - ``delu``
     - An extension to ``torch``.
   * - ``delu.cuda``
     - An extension to ``torch.cuda``.
   * - ``delu.nn``
     - An extension to ``torch.nn``.
   * - ``delu.random``
     - An extension to ``torch.random``.
   * - ``delu.tools``
     - Handy tools for common scenarios (e.g. for implementing training loops).

**Project status** 🧪
*Until the release of the version 0.1.0, DeLU should be considered as experimental.
All changes are carefully documented in the release notes.*

Installation
------------

.. code-block:: none

    pip install delu

Usage
-----

*DeLU is a toolbox, not a framework,
so you can learn things and start using them in any order.*

The "Usage & API" section on the website
provides usage examples, explanations and docstrings
--- it is the main source of knowledge about DeLU.

How to contribute
-----------------

- Use `issues <https://github.com/Yura52/delu/issues>`_
  to report bugs, share ideas and give feedback.
- For pull requests, see
  `CONTRIBUTING.md <https://github.com/Yura52/delu/blob/main/CONTRIBUTING.md>`_.
